@@ -182,6 +182,12 @@ class Config(MutableMapping[str, str]):
         "python.use_venv": ConfigItem(
             "Use virtual environments when available", True, env_var="PDM_USE_VENV", coerce=ensure_boolean
         ),
+        "python.use_python_version": ConfigItem(
+            "Use .python-version file next to pyproject.toml to find python interpreters",
+            True,
+            env_var="PDM_USE_PYTHON_VERSION",
+            coerce=ensure_boolean,
+        ),
         "python.install_root": ConfigItem(
             "The root directory to install python interpreters",
             global_only=True,
@@ -327,7 +333,7 @@ class Config(MutableMapping[str, str]):
             if repo is None:
                 raise KeyError(f"No {parts[0]} named {parts[1]}")
             if len(parts) >= 3:
-                repo.populate_auth()
+                repo.populate_keyring_auth()
                 return getattr(repo, parts[2])
             return repo
 
@@ -353,7 +359,7 @@ class Config(MutableMapping[str, str]):
                 raise PdmUsageError(f"Set {parts[0]} config with [success]{parts[0]}.{{name}}.{{attr}}")
             index_key = ".".join(parts[:2])
             username = self._data.get(index_key, {}).get("username")  # type: ignore[call-overload]
-            service = f'pdm-{index_key.replace(".", "-")}'
+            service = f"pdm-{index_key.replace('.', '-')}"
             if (
                 parts[2] == "password"
                 and self.is_global
@@ -402,7 +408,7 @@ class Config(MutableMapping[str, str]):
                 raise PdmUsageError(f"Should specify the name of {parts[0]}")
             index_key = ".".join(parts[:2])
             username = self._data.get(index_key, {}).get("username")  # type: ignore[call-overload]
-            service = f'pdm-{index_key.replace(".", "-")}'
+            service = f"pdm-{index_key.replace('.', '-')}"
             if len(parts) >= 3:
                 index_key, attr = key.rsplit(".", 1)
                 if attr == "password" and username:
